Documentation
¶
Overview ¶
Package envrtr provides functional to pull out (apply) and retract (rollback) changes for environment variables.
Package envrtr provides functional to pull out (apply) and retract (rollback) changes for environment variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EnvRetractor ¶
type EnvRetractor struct {
// contains filtered or unexported fields
}
EnvRetractor provides functional for pull out and retracts environment variables.
func (*EnvRetractor) PullOut ¶
func (r *EnvRetractor) PullOut() Retractor
PullOut sets provided values for environment variables.
func (*EnvRetractor) Retract ¶
func (r *EnvRetractor) Retract()
Retract rolls back the values of an environment variables to its original state.
type EnvUnsetRetractor ¶ added in v1.1.0
type EnvUnsetRetractor struct {
// contains filtered or unexported fields
}
EnvUnsetRetractor provides functional for unseting environment variables and return their original values.
func (*EnvUnsetRetractor) PullOut ¶ added in v1.1.0
func (r *EnvUnsetRetractor) PullOut() Retractor
PullOut sets provided values for environment variables.
func (*EnvUnsetRetractor) Retract ¶ added in v1.1.0
func (r *EnvUnsetRetractor) Retract()
Retract rolls back the values of an environment variables to its original state.
type Retractor ¶ added in v1.2.0
type Retractor interface {
PullOut() Retractor
Retract()
}
Retractor common interface for retractors.
func NewEnvRetractor ¶
NewEnvRetractor constructor for EnvRetractor.
func NewEnvUnsetRetractor ¶ added in v1.1.0
NewEnvUnsetRetractor constructor for EnvUnsetRetractor.